---
layout: home
---

# G4CAMP: Cascade and Muon Propagator (Geant4-based)

G4CAMP is a Pyhton module based on the [Geant4](https://geant4.web.cern.ch) framework and [geant4_pybind](https://github.com/HaarigerHarald/geant4_pybind) pythonization. It simulates propagation of particles of energies up to 1 PeV in a water volume taking into acccount electro-magnetic and hadronic interactions. Emission of Cherenkov photons can be optionally enabled but photons won't be propagated.

## Useful for:

 - Full simulation of electro-magnetic and hadron cascades
 - Fast simulation of initial phase of cascades
 - Using as part of a larger simulation tool written in Python
 - Standalone simulation
 - 3D visulazation


Any suggestions on extending G4CAMP functionalty, bug reports or other feedback are welcome: [contact](mailto:yum@jinr.ru).
